Tutorials for bgsegm module {#tutorial_table_of_content_bgsegm}
===============================================================

-   @subpage tutorial_bgsegm_bg_subtraction

    In several applications, we need to extract foreground for further operations like object tracking. Background Subtraction is a well-known method in those cases.
